@@ -16,7 +16,6 @@
     along with SnoreNotify.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "snorenotify.h"
-#include "libsnore/log.h"
 #include "libsnore/version.h"
 
 #include <QApplication>
@@ -24,8 +23,8 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    app.setApplicationName(QLatin1String("SnoreNotify"));
-    app.setOrganizationName(QLatin1String("SnoreNotify"));
+    app.setApplicationName(QStringLiteral("SnoreNotify"));
+    app.setOrganizationName(QStringLiteral("SnoreNotify"));
     app.setApplicationVersion(Snore::Version::version());
     app.setQuitOnLastWindowClosed(false);
 
