@@ -28,10 +28,10 @@ using namespace Snore;
 SnoreNotify::SnoreNotify()
 {
     m_trayIcon = new TrayIcon();
-    SnoreCore::instance().loadPlugins(SnorePlugin::ALL);
+    SnoreCore::instance().loadPlugins(SnorePlugin::All);
     m_trayIcon->initConextMenu();
 
-    snoreDebug(SNORE_DEBUG) << "Snorenotfiy initialized with" << SnoreCore::instance().primaryNotificationBackend();
+    qCDebug(SNORE) << "Snorenotfiy initialized with" << SnoreCore::instance().primaryNotificationBackend();
 }
 
 SnoreNotify::~SnoreNotify()
