@@ -17,22 +17,24 @@
 */
 
 #include "trayicon.h"
-#include "libsnore/settingsdialog.h"
+#include "libsnore/settings/settingsdialog.h"
 #include "libsnore/snore.h"
 #include "libsnore/snore_p.h"
 
 #include <QAction>
 #include <QApplication>
+#include <QAbstractButton>
 #include <QDialogButtonBox>
 #include <QMenu>
 #include <QSystemTrayIcon>
+#include <QLayout>
 
 #include "libsnore/version.h"
 
 using namespace Snore;
 
 TrayIcon::TrayIcon():
-    m_trayIcon(new QSystemTrayIcon(QIcon(QLatin1String(":/root/snore.png"))))
+    m_trayIcon(new QSystemTrayIcon(QIcon(QStringLiteral(":/root/snore.png"))))
 {
     SnoreCorePrivate::instance()->defaultApplication().hints().setValue("use-markup", true);
     SnoreCorePrivate::instance()->defaultApplication().hints().setValue("tray-icon", QVariant::fromValue(QPointer<QSystemTrayIcon>(m_trayIcon)));
@@ -58,7 +60,7 @@ void TrayIcon::initConextMenu()
             m_settings->setVisible(false);
             break;
         default:
-            snoreDebug(SNORE_WARNING) << "unhandled role" << button->text() << box->buttonRole(button);
+            qCWarning(SNORE) << "unhandled role" << button->text() << box->buttonRole(button);
         }
     });
     m_settings->layout()->addWidget(box);
@@ -67,7 +69,7 @@ void TrayIcon::initConextMenu()
 
     m_trayIcon->setVisible(true);
 
-    m_trayMenu = new QMenu(QLatin1String("SnoreNotify"));
+    m_trayMenu = new QMenu(QStringLiteral("SnoreNotify"));
     QString version = QLatin1String("SnoreNotify ") + Version::version();
     if (!Version::revision().isEmpty()) {
         version += QLatin1String("-") + Version::revision();
