@@ -20,7 +20,7 @@
 #include "lambdahint.h"
 #include "snore_p.h"
 
-#include <QApplication>
+#include <QGuiApplication>
 
 using namespace Snore;
 
@@ -36,7 +36,7 @@ ApplicationData::ApplicationData(const QString &key, const QString &name, const
     m_hint.setValue("pushover-token", QLatin1String("aFB1TPCyZkkr7mubCGEKy5vJEWak9t"));
     m_hint.setValue("use-markup", false);
     m_hint.setValue("silent", QVariant::fromValue(LambdaHint([]() {
-        return SnoreCore::instance().settingsValue(QLatin1String("Silent"), LOCAL_SETTING);
+        return SnoreCore::instance().settingsValue(QStringLiteral("Silent"), LocalSetting);
     })));
 
 }
