@@ -21,7 +21,6 @@
 #include "notification/icon.h"
 #include "notification/notification_p.h"
 #include "plugins/plugincontainer.h"
-#include <Qt>
 
 using namespace Snore;
 
@@ -92,12 +91,12 @@ Application &Notification::application() const
     return d->m_application;
 }
 
-QString Notification::title(Utils::MARKUP_FLAGS flags) const
+QString Notification::title(Utils::MarkupFlags flags) const
 {
     return d->resolveMarkup(d->m_title, flags);
 }
 
-QString Notification::text(Utils::MARKUP_FLAGS flags) const
+QString Notification::text(Utils::MarkupFlags flags) const
 {
     return d->resolveMarkup(d->m_text, flags);
 }
@@ -152,12 +151,12 @@ void Notification::addActiveIn(const QObject *o)
     bool contains = d->m_activeIn.contains(o);
     Q_ASSERT_X(!contains, Q_FUNC_INFO, "already active");
     if (contains) {
-        snoreDebug(SNORE_WARNING) << o << "already active in" << id();
+        qCWarning(SNORE) << o << "already active in" << id();
         return;
     }
     d->m_activeIn.insert(o);
     SnoreCorePrivate::instance()->m_activeNotifications[id()] = *this;
-    snoreDebug(SNORE_INFO) << SnoreCorePrivate::instance()->m_activeNotifications.size();
+    qCDebug(SNORE) << SnoreCorePrivate::instance()->m_activeNotifications.size();
 }
 
 bool Notification::isActiveIn(const QObject *o) const
@@ -170,7 +169,7 @@ bool Notification::removeActiveIn(const QObject *o)
     bool out = d->m_activeIn.remove(o);
     if (d->m_activeIn.isEmpty()) {
         SnoreCorePrivate::instance()->m_activeNotifications.remove(id());
-        snoreDebug(SNORE_INFO) << SnoreCorePrivate::instance()->m_activeNotifications.size();
+        qCDebug(SNORE) << SnoreCorePrivate::instance()->m_activeNotifications.size();
     }
     return out;
 }
@@ -182,7 +181,7 @@ NotificationData *Notification::data()
 
 int Notification::defaultTimeout()
 {
-    return SnoreCore::instance().settingsValue(QLatin1String("Timeout"), LOCAL_SETTING).toInt();
+    return SnoreCore::instance().settingsValue(QStringLiteral("Timeout"), LocalSetting).toInt();
 }
 
 QDataStream &operator<< (QDataStream &stream, const Notification &noti)
@@ -197,11 +196,11 @@ QDebug operator <<(QDebug debug, const Snore::Notification::CloseReasons &flags)
 {
     debug.nospace() << "CloseReasons(";
     switch (flags) {
-        debugPrintEnum(Notification::NONE);
-        debugPrintEnum(Notification::TIMED_OUT);
-        debugPrintEnum(Notification::DISMISSED);
-        debugPrintEnum(Notification::ACTIVATED);
-        debugPrintEnum(Notification::REPLACED);
+        debugPrintEnum(Notification::None);
+        debugPrintEnum(Notification::TimedOut);
+        debugPrintEnum(Notification::Dismissed);
+        debugPrintEnum(Notification::Activated);
+        debugPrintEnum(Notification::Replaced);
     }
     return debug.space();
 }
@@ -210,9 +209,9 @@ QDebug operator<< (QDebug debug, const Snore::Notification::Prioritys &flags)
 {
     debug.nospace() << "Prioritys(";
     switch (flags) {
-        debugPrintEnum(Notification::LOW);
-        debugPrintEnum(Notification::NORMAL);
-        debugPrintEnum(Notification::HIGH);
+        debugPrintEnum(Notification::Low);
+        debugPrintEnum(Notification::Normal);
+        debugPrintEnum(Notification::High);
     default:
         debug << QByteArray::number(flags, 16) << ")";
     }
