@@ -19,7 +19,6 @@
 #include "notification/notification_p.h"
 #include "notification/icon.h"
 #include "../hint.h"
-#include "libsnore/log.h"
 #include "libsnore/plugins/plugins.h"
 #include "libsnore/snore.h"
 
@@ -34,7 +33,7 @@ uint NotificationData::m_idCount = 1;
 NotificationData::NotificationData(const Snore::Application &application, const Snore::Alert &alert, const QString &title, const QString &text, const Icon &icon,
                                    int timeout, Notification::Prioritys priority):
     m_id(m_idCount++),
-    m_timeout(priority == Notification::EMERGENCY ? 0 : timeout),
+    m_timeout(priority == Notification::Emergency ? 0 : timeout),
     m_application(application),
     m_alert(alert),
     m_title(title),
@@ -44,13 +43,13 @@ NotificationData::NotificationData(const Snore::Application &application, const
     m_hints(m_application.constHints())
 {
     notificationCount++;
-    snoreDebug(SNORE_INFO) << "Creating Notification: ActiveNotifications" << notificationCount << "id" << m_id;
-    snoreDebug(SNORE_INFO) << title << text;
+    qCDebug(SNORE) << "Creating Notification: ActiveNotifications" << notificationCount << "id" << m_id;
+    qCDebug(SNORE) << title << text;
 }
 
 Snore::NotificationData::NotificationData(const Notification &old, const QString &title, const QString &text, const Icon &icon, int timeout, Notification::Prioritys priority):
     m_id(m_idCount++),
-    m_timeout(priority == Notification::EMERGENCY ? 0 : timeout),
+    m_timeout(priority == Notification::Emergency ? 0 : timeout),
     m_application(old.application()),
     m_alert(old.alert()),
     m_title(title),
@@ -61,15 +60,15 @@ Snore::NotificationData::NotificationData(const Notification &old, const QString
     m_toReplace(old)
 {
     notificationCount++;
-    snoreDebug(SNORE_INFO) << "Creating Notification: ActiveNotifications" << notificationCount << "id" << m_id;
-    snoreDebug(SNORE_INFO) << title << text;
+    qCDebug(SNORE) << "Creating Notification: ActiveNotifications" << notificationCount << "id" << m_id;
+    qCDebug(SNORE) << title << text;
 }
 
 NotificationData::~NotificationData()
 {
     stopTimeoutTimer();
     notificationCount--;
-    snoreDebug(SNORE_INFO) << "Deleting Notification: ActiveNotifications" << notificationCount << "id" << m_id << "Close Reason:" << m_closeReason;
+    qCDebug(SNORE) << "Deleting Notification: ActiveNotifications" << notificationCount << "id" << m_id << "Close Reason:" << m_closeReason;
 }
 
 void NotificationData::setActionInvoked(const Snore::Action &action)
@@ -83,10 +82,10 @@ void NotificationData::setCloseReason(Snore::Notification::CloseReasons r)
     stopTimeoutTimer();
 }
 
-QString NotificationData::resolveMarkup(const QString &string, Utils::MARKUP_FLAGS flags)
+QString NotificationData::resolveMarkup(const QString &string, Utils::MarkupFlags flags)
 {
     if (!m_hints.value("use-markup").toBool()) {
-        if (flags == Utils::NO_MARKUP) {
+        if (flags == Utils::NoMarkup) {
             return string;
         } else {
             return Utils::normalizeMarkup(string.toHtmlEscaped(), flags);
@@ -119,7 +118,7 @@ const SnorePlugin *NotificationData::source() const
 bool NotificationData::sourceAndTargetAreSimilar(const SnorePlugin *target)
 {
     if (source() && source()->name() == target->name()) {
-        snoreDebug(SNORE_DEBUG) << "Source" << source() << "and Target" << target << "are the same.";
+        qCDebug(SNORE) << "Source" << source() << "and Target" << target << "are the same.";
         return true;
     }
     return false;
