@@ -26,7 +26,7 @@ Action::Action():
 
 }
 
-Action::Action(int id, QString name):
+Action::Action(int id, const QString &name):
     m_id(id),
     m_name(name)
 {
