@@ -17,22 +17,22 @@
 */
 
 #include "plugincontainer.h"
-#include "../snore.h"
-#include "../snore_p.h"
+#include "libsnore/snore.h"
+#include "libsnore/snore_p.h"
 #include "plugins.h"
 #include "snorebackend.h"
 #include "snorefrontend.h"
-#include "../version.h"
+#include "libsnore/version.h"
 
 #include <QDir>
-#include <QApplication>
+#include <QGuiApplication>
 #include <QTime>
 
 using namespace Snore;
 
 QHash<SnorePlugin::PluginTypes, QHash<QString, PluginContainer *> > PluginContainer::s_pluginCache;
 
-PluginContainer::PluginContainer(QString fileName, QString pluginName, SnorePlugin::PluginTypes type):
+PluginContainer::PluginContainer(const QString &fileName, const QString &pluginName, SnorePlugin::PluginTypes type):
     m_pluginFile(fileName),
     m_pluginName(pluginName),
     m_pluginType(type),
@@ -49,7 +49,7 @@ PluginContainer::~PluginContainer()
 SnorePlugin *PluginContainer::load()
 {
     if (!m_loader.isLoaded() && !m_loader.load()) {
-        snoreDebug(SNORE_WARNING) << "Failed loading plugin: " << m_loader.errorString();
+        qCWarning(SNORE) << "Failed loading plugin: " << m_loader.errorString();
         return nullptr;
     }
     if (!m_plugin) {
@@ -88,25 +88,23 @@ bool PluginContainer::isLoaded() const
 
 void PluginContainer::updatePluginCache()
 {
-    snoreDebug(SNORE_DEBUG) << "Updating plugin cache";
-    for (auto list : s_pluginCache) {
-        foreach(PluginContainer * p, list.values()) {
-            delete p;
-        }
+    qCDebug(SNORE) << "Updating plugin cache";
+    foreach(PluginContaienrHash list, s_pluginCache.values()) {
+        qDeleteAll(list);
         list.clear();
     }
 
     foreach(const SnorePlugin::PluginTypes type, SnorePlugin::types()) {
         foreach(const QFileInfo & file, pluginDir().entryInfoList(
                     QStringList(pluginFileFilters(type)), QDir::Files)) {
-            snoreDebug(SNORE_DEBUG) << "adding" << file.absoluteFilePath();
+            qCDebug(SNORE) << "adding" << file.absoluteFilePath();
             QPluginLoader loader(file.absoluteFilePath());
-            QJsonObject data = loader.metaData()[QLatin1String("MetaData")].toObject();
-            QString name = data.value(QLatin1String("name")).toString();
+            QJsonObject data = loader.metaData()[QStringLiteral("MetaData")].toObject();
+            QString name = data.value(QStringLiteral("name")).toString();
             if (!name.isEmpty()) {
                 PluginContainer *info = new PluginContainer(file.fileName(), name, type);
                 s_pluginCache[type].insert(name, info);
-                snoreDebug(SNORE_DEBUG) << "added" << name << "to cache";
+                qCDebug(SNORE) << "added" << type << ":" << name << "to cache";
             }
         }
     }
@@ -118,11 +116,11 @@ const QHash<QString, PluginContainer *> PluginContainer::pluginCache(SnorePlugin
         QTime time;
         time.start();
         updatePluginCache();
-        snoreDebug(SNORE_DEBUG) << "Plugins loaded in:" << time.elapsed();
+        qCDebug(SNORE) << "Plugins loaded in:" << time.elapsed();
     }
 
     QHash<QString, PluginContainer *> out;
-    for (auto t : SnorePlugin::types()) {
+    for (auto &t : SnorePlugin::types()) {
         if (t & type) {
             out.unite(s_pluginCache.value(t));
         }
@@ -151,23 +149,23 @@ const QDir &PluginContainer::pluginDir()
 #endif
         QString suffix = QLatin1String("/libsnore") + QLatin1String(SNORE_SUFFIX);
         list << appDir
-             << QLatin1String(LIBSNORE_PLUGIN_PATH)
              << appDir + suffix
-             << appDir + QLatin1String("/../lib/plugins") + suffix
-             << appDir + QLatin1String("/../lib64/plugins") + suffix;
-        for (const QString &p : list) {
+             << appDir + QStringLiteral("/../lib/plugins") + suffix
+             << appDir + QStringLiteral("/../lib64/plugins") + suffix
+             << QStringLiteral(LIBSNORE_PLUGIN_PATH);
+        foreach(const QString & p, list) {
             path = QDir(p);
 
             if (!path.entryInfoList(pluginFileFilters()).isEmpty()) {
                 break;
             } else {
-                snoreDebug(SNORE_DEBUG) << "Possible pluginpath:" << path.absolutePath() << "does not contain plugins.";
+                qCDebug(SNORE) << "Possible pluginpath:" << path.absolutePath() << "does not contain plugins.";
             }
         }
         if (path.entryInfoList(pluginFileFilters()).isEmpty()) {
-            snoreDebug(SNORE_WARNING) << "Couldnt find any plugins";
+            qCWarning(SNORE) << "Couldnt find any plugins";
         }
-        snoreDebug(SNORE_INFO) << "PluginPath is :" << path.absolutePath();
+        qCDebug(SNORE) << "PluginPath is :" << path.absolutePath();
     }
     return path;
 }
