@@ -25,7 +25,7 @@
 
 #include <QDebug>
 #include <QMetaEnum>
-#include <QApplication>
+#include <QGuiApplication>
 
 using namespace Snore;
 
@@ -33,13 +33,13 @@ SnorePlugin::SnorePlugin()
 {
     Q_ASSERT_X(thread() == qApp->thread(), Q_FUNC_INFO, "Plugin initialized in wrong thread");
     if (thread() != qApp->thread()) {
-        snoreDebug(SNORE_WARNING) << "Plugin initialized in wrong thread.";
+        qCWarning(SNORE) << "Plugin initialized in wrong thread.";
     }
 }
 
 SnorePlugin::~SnorePlugin()
 {
-    snoreDebug(SNORE_DEBUG) << name() << this << "deleted";
+    qCDebug(SNORE) << name() << this << "deleted";
 }
 
 bool SnorePlugin::isEnabled() const
@@ -62,13 +62,14 @@ void SnorePlugin::setDefaultSettingsValue(const QString &key, const QVariant &va
     SnoreCore::instance().setDefaultSettingsValue(normaliseKey(key), value, type);
 }
 
-Snore::PluginSettingsWidget *SnorePlugin::settingsWidget()
+const Hint &SnorePlugin::constHints() const
 {
-    if (type() != SnorePlugin::BACKEND) {
-        // don't display a useless default widget for backends
-        return new PluginSettingsWidget(this);
-    }
-    return nullptr;
+    return const_cast<Hint &>(const_cast<SnorePlugin *>(this)->hints());
+}
+
+Hint &SnorePlugin::hints()
+{
+    return m_hints;
 }
 
 QString SnorePlugin::normaliseKey(const QString &key) const
@@ -82,12 +83,6 @@ const QString &SnorePlugin::name() const
     return m_container->name();
 }
 
-SnorePlugin::PluginTypes SnorePlugin::type() const
-{
-    Q_ASSERT_X(m_container, Q_FUNC_INFO, "Plugin container not set.");
-    return m_container->type();
-}
-
 const QString SnorePlugin::typeName() const
 {
     return SnorePlugin::typeToString(type());
@@ -105,18 +100,18 @@ QString SnorePlugin::errorString() const
 
 QString SnorePlugin::settingsVersion() const
 {
-    return QLatin1String("v1");
+    return QStringLiteral("v1");
 }
 
 void SnorePlugin::setDefaultSettings()
 {
-    setDefaultSettingsValue(QLatin1String("Enabled"), false, LOCAL_SETTING);
+    setDefaultSettingsValue(QStringLiteral("Enabled"), false, LocalSetting);
 }
 
 void SnorePlugin::setErrorString(const QString &_error)
 {
     m_error = _error;
-    snoreDebug(SNORE_WARNING) << name() << "encountered an error:" << m_error;
+    qCWarning(SNORE) << name() << "encountered an error:" << m_error;
     disable();
     emit error(_error);
 }
@@ -149,11 +144,12 @@ QString SnorePlugin::typeToString(const SnorePlugin::PluginTypes t)
     return QString::fromLatin1(SnorePlugin::staticMetaObject.enumerator(SnorePlugin::staticMetaObject.indexOfEnumerator("PluginType")).valueToKey(t));
 }
 
-QList<SnorePlugin::PluginTypes> SnorePlugin::types()
+const QList<SnorePlugin::PluginTypes> &SnorePlugin::types()
 {
     static QList<SnorePlugin::PluginTypes> t;
     if (t.isEmpty()) {
         QMetaEnum e = SnorePlugin::staticMetaObject.enumerator(SnorePlugin::staticMetaObject.indexOfEnumerator("PluginType"));
+        t.reserve(e.keyCount());
         for (int i = 0; i < e.keyCount(); ++i) {
             t << (SnorePlugin::PluginTypes) e.value(i);
         }
