@@ -16,7 +16,6 @@
     along with SnoreNotify.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "utils.h"
-#include "log.h"
 
 #ifdef Q_OS_WIN
 #include <windows.h>
@@ -44,66 +43,73 @@ Utils::~Utils()
 
 }
 
-void Utils::bringWindowToFront(qlonglong _wid, bool focus)
+void Utils::bringWindowToFront(const QWindow *window, bool focus)
 {
 #ifdef Q_OS_WIN
-    HWND wid = (HWND)_wid;
+    bringWindowToFront((HWND)window->winId(), focus);
+#else
+    // TODO: implement
+    Q_UNUSED(window);
+    Q_UNUSED(focus);
+#endif
+}
+
+#ifdef Q_OS_WIN
+void Utils::bringWindowToFront(HWND wid, bool focus)
+{
     int active = attatchToActiveProcess();
     SetForegroundWindow(wid);
     if (focus) {
         SetFocus(wid);
     }
     detatchActiveProcess(active);
-#else
-    Q_UNUSED(_wid);
-    Q_UNUSED(focus);
-#endif
 }
+#endif
 
-void Utils::raiseWindowToFront(qlonglong wid)
+void Utils::raiseWindowToFront(const QWindow *window)
 {
     // Looks like qt is handling it on linux.
 #ifdef Q_OS_WIN
     int active = attatchToActiveProcess();
-    SetWindowPos((HWND)wid, HWND_TOP, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE | SWP_NOACTIVATE);
+    SetWindowPos((HWND)window->winId(), HWND_TOP, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE | SWP_NOACTIVATE);
     detatchActiveProcess(active);
 #else
-    Q_UNUSED(wid);
+    Q_UNUSED(window);
 #endif
 }
 
 #define HTML_REPLACE(STRING, PATTERN){\
         static QRegExp regexp(QLatin1String(PATTERN));\
-        STRING = STRING.replace(regexp, QLatin1String("\\1"));\
+        STRING = STRING.replace(regexp, QStringLiteral("\\1"));\
     }\
      
-QString Utils::normalizeMarkup(QString string, MARKUP_FLAGS tags)
+QString Utils::normalizeMarkup(QString string, MarkupFlags tags)
 {
     static QMutex mutex;
-    if (tags == ALL_MARKUP) {
+    if (tags == AllMarkup) {
         return string;
-    } else if (tags == NO_MARKUP) {
+    } else if (tags == NoMarkup) {
         return QTextDocumentFragment::fromHtml(string).toPlainText();
     }
 
     QMutexLocker lock(&mutex);
-    if (~tags & Utils::BREAK) {
+    if (~tags & Utils::Break) {
         static QRegExp br(QLatin1String("<br>"));
-        string = string.replace(br, QLatin1String("\n"));
+        string = string.replace(br, QStringLiteral("\n"));
     }
-    if (~tags & Utils::HREF) {
+    if (~tags & Utils::Href) {
         HTML_REPLACE(string, "<a href=.*>([^<]*)</a>");
     }
-    if (~tags & Utils::ITALIC) {
+    if (~tags & Utils::Italic) {
         HTML_REPLACE(string, "<i>([^<]*)</i>");
     }
-    if (~tags & Utils::BOLD) {
+    if (~tags & Utils::Bold) {
         HTML_REPLACE(string, "<b>([^<]*)</b>");
     }
-    if (~tags & Utils::UNDERLINE) {
+    if (~tags & Utils::Underline) {
         HTML_REPLACE(string, "<u>([^<]*)</u>");
     }
-    if (~tags & Utils::FONT) {
+    if (~tags & Utils::Font) {
         HTML_REPLACE(string, "<font.*>([^<]*)</font>");
     }
     return string;
