@@ -7,7 +7,7 @@ class  FreedesktopBackend: public Snore::SnoreBackend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreBackend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "snore_plugin.json")
 public:
     FreedesktopBackend();
     ~FreedesktopBackend() = default;
@@ -19,8 +19,8 @@ public Q_SLOTS:
     void slotNotify(Snore::Notification notification) override;
     void slotCloseNotification(Snore::Notification notification) override;
 
-    void slotActionInvoked(const uint &id, const QString &actionID);
-    void slotNotificationClosed(const uint &id, const uint &reason);
+    void slotActionInvoked(const uint id, const QString &actionID);
+    void slotNotificationClosed(const uint id, const uint reason);
 
 private:
     org::freedesktop::Notifications *m_interface;
