@@ -17,7 +17,6 @@
 */
 
 #include "growlbackend.h"
-#include "growlsettings.h"
 
 #include "libsnore/snore.h"
 #include "libsnore/snore_p.h"
@@ -34,23 +33,23 @@ GrowlBackend::GrowlBackend()
     s_instance = this;
 
     auto func = [](growl_callback_data * data)->void {
-        snoreDebug(SNORE_DEBUG) << data->id << QString::fromUtf8(data->reason) << QString::fromUtf8(data->data);
+        qCDebug(SNORE) << data->id << QString::fromUtf8(data->reason) << QString::fromUtf8(data->data);
         Notification n = Snore::SnoreCore::instance().getActiveNotificationByID(data->id);
         if (!n.isValid())
         {
             return;
         }
-        Notification::CloseReasons r = Notification::NONE;
+        Notification::CloseReasons r = Notification::None;
         std::string reason(data->reason);
         if (reason == "TIMEDOUT")
         {
-            r = Notification::TIMED_OUT;
+            r = Notification::TimedOut;
         } else if (reason == "CLOSED")
         {
-            r = Notification::DISMISSED;
+            r = Notification::Dismissed;
         } else if (reason == "CLICK")
         {
-            r = Notification::ACTIVATED;
+            r = Notification::Activated;
             s_instance->slotNotificationActionInvoked(n);
         }
         s_instance->closeNotification(n, r);
@@ -65,7 +64,7 @@ GrowlBackend::~GrowlBackend()
 
 bool GrowlBackend::isReady()
 {
-    bool running = Growl::isRunning(GROWL_TCP, settingsValue(QLatin1String("Host")).toString().toUtf8().constData());
+    bool running = Growl::isRunning(GROWL_TCP, settingsValue(QStringLiteral("Host")).toString().toUtf8().constData());
     if (!running) {
         setErrorString(tr("%1 is not running.").arg(name()));
     }
@@ -74,15 +73,16 @@ bool GrowlBackend::isReady()
 
 void GrowlBackend::slotRegisterApplication(const Application &application)
 {
-    snoreDebug(SNORE_DEBUG) << application.name();
+    qCDebug(SNORE) << application.name();
     std::vector<std::string> alerts;
+    alerts.reserve(application.alerts().size());
     foreach(const Alert & a, application.alerts()) {
-        snoreDebug(SNORE_DEBUG) << a.name();
+        qCDebug(SNORE) << a.name();
         alerts.push_back(a.name().toUtf8().constData());
     }
 
-    Growl *growl = new Growl(GROWL_TCP, settingsValue(QLatin1String("Host")).toString().toUtf8().constData(),
-                             settingsValue(QLatin1String("Password")).toString().toUtf8().constData(),
+    Growl *growl = new Growl(GROWL_TCP, settingsValue(QStringLiteral("Host")).toString().toUtf8().constData(),
+                             settingsValue(QStringLiteral("Password")).toString().toUtf8().constData(),
                              application.name().toUtf8().constData());
     m_applications.insert(application.name(), growl);
     growl->Register(alerts, application.icon().localUrl(QSize(128, 128)).toUtf8().constData());
@@ -102,7 +102,7 @@ void GrowlBackend::slotNotify(Notification notification)
 {
     Growl *growl = m_applications.value(notification.application().name());
     QString alert = notification.alert().name();
-    snoreDebug(SNORE_DEBUG) << "Notify Growl:" << notification.application() << alert << notification.title();
+    qCDebug(SNORE) << "Notify Growl:" << notification.application() << alert << notification.title();
 
     GrowlNotificationData data(alert.toUtf8().constData(), notification.id(),
                                notification.title().toUtf8().constData(),
@@ -115,15 +115,10 @@ void GrowlBackend::slotNotify(Notification notification)
     slotNotificationDisplayed(notification);
 }
 
-PluginSettingsWidget *GrowlBackend::settingsWidget()
-{
-    return new GrowlSettings(this);
-}
-
 void GrowlBackend::setDefaultSettings()
 {
     SnoreBackend::setDefaultSettings();
-    setDefaultSettingsValue(QLatin1String("Host"), QLatin1String("localhost"));
-    setDefaultSettingsValue(QLatin1String("Password"), QString());
+    setDefaultSettingsValue(QStringLiteral("Host"), QLatin1String("localhost"));
+    setDefaultSettingsValue(QStringLiteral("Password"), QString());
 }
 
