@@ -27,12 +27,11 @@ class GrowlBackend: public Snore::SnoreBackend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreBackend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "snore_plugin.json")
 
 public:
     GrowlBackend();
     ~GrowlBackend();
-    Snore::PluginSettingsWidget *settingsWidget() override;
     bool isReady() override;
 
 protected:
