@@ -17,7 +17,6 @@
 */
 
 #include "snarl.h"
-#include "snarlsettings.h"
 
 #include "libsnore/snore.h"
 #include "libsnore/snore_p.h"
@@ -26,6 +25,7 @@
 #include "libsnore/plugins/snorebackend.h"
 #include "libsnore/notification/notification_p.h"
 
+#include <QApplication>
 #include <QWidget>
 
 #include <iostream>
@@ -66,44 +66,44 @@ public:
                     notification =  m_snarl->m_idMap.value(msg->lParam);
                 }
 
-                Notification::CloseReasons reason = Notification::NONE;
+                Notification::CloseReasons reason = Notification::None;
                 switch (action) {
                 case SnarlEnums::CallbackInvoked:
-                    reason = Notification::ACTIVATED;
-                    snoreDebug(SNORE_DEBUG) << "Notification clicked";
+                    reason = Notification::Activated;
+                    qCDebug(SNORE) << "Notification clicked";
                     break;
                 case SnarlEnums::NotifyAction:
-                    reason = Notification::ACTIVATED;
-                    snoreDebug(SNORE_DEBUG) << "Notification action invoked";
+                    reason = Notification::Activated;
+                    qCDebug(SNORE) << "Notification action invoked";
                     if (notification.isValid()) {
                         m_snarl->slotNotificationActionInvoked(notification, notification.actions().value(data));
                     }
                     break;
                 case SnarlEnums::CallbackClosed:
-                    reason = Notification::DISMISSED;
-                    snoreDebug(SNORE_DEBUG) << "Notification dismissed";
+                    reason = Notification::Dismissed;
+                    qCDebug(SNORE) << "Notification dismissed";
                     break;
                 case SnarlEnums::CallbackTimedOut:
-                    reason = Notification::TIMED_OUT;
-                    snoreDebug(SNORE_DEBUG) << "Notification timed out";
+                    reason = Notification::TimedOut;
+                    qCDebug(SNORE) << "Notification timed out";
                     break;
                 //away stuff
                 case SnarlEnums::SnarlUserAway:
-                    snoreDebug(SNORE_DEBUG) << "Snalr user has gone away";
+                    qCDebug(SNORE) << "Snalr user has gone away";
                     return true;
                 case SnarlEnums::SnarlUserBack:
-                    snoreDebug(SNORE_DEBUG) << "Snalr user has returned";
+                    qCDebug(SNORE) << "Snalr user has returned";
                     return true;
                 default:
-                    snoreDebug(SNORE_WARNING) << "Unknown snarl action found!!";
+                    qCWarning(SNORE) << "Unknown snarl action found!!";
                     return false;
                 }
                 if (notification.isValid()) {
                     m_snarl->requestCloseNotification(notification, reason);
                     m_snarl->m_idMap.take(msg->lParam);
                 } else {
-                    snoreDebug(SNORE_WARNING) << "Snarl notification already closed" << msg->lParam << action;
-                    snoreDebug(SNORE_WARNING) << m_snarl->m_idMap;
+                    qCWarning(SNORE) << "Snarl notification already closed" << msg->lParam << action;
+                    qCWarning(SNORE) << m_snarl->m_idMap;
                 }
                 return true;
             }
@@ -117,20 +117,15 @@ private:
 
 };
 
-SnarlBackend::SnarlBackend():
-    m_eventLoop(new SnarlBackend::SnarlWidget(this))
+SnarlBackend::SnarlBackend()
 {
-
 }
 
 SnarlBackend::~SnarlBackend()
 {
-    delete m_eventLoop;
-}
-
-PluginSettingsWidget *SnarlBackend::settingsWidget()
-{
-    return new SnarlSettings(this);
+    if (m_eventLoop) {
+        delete m_eventLoop;
+    }
 }
 
 bool SnarlBackend::canCloseNotification() const
@@ -145,6 +140,14 @@ bool SnarlBackend::canUpdateNotification() const
 
 bool SnarlBackend::isReady()
 {
+    if (!qobject_cast< QApplication * >(qApp)) {
+        setErrorString(tr("This plugin only works with QApplication"));
+        return false;
+    }
+
+    if (!m_eventLoop) {
+        m_eventLoop = new SnarlBackend::SnarlWidget(this);
+    }
     bool running = SnarlInterface::IsSnarlRunning();
     if (!running) {
         setErrorString(tr("%1 is not running.").arg(name()));
@@ -177,7 +180,7 @@ void SnarlBackend::slotRegisterApplication(const Application &application)
                     application.icon().localUrl(QSize(128, 128)).toUtf8().constData(),
                     password.isEmpty() ? 0 : password.toUtf8().constData(),
                     (HWND)m_eventLoop->winId(), SNORENOTIFIER_MESSAGE_ID);
-    snoreDebug(SNORE_DEBUG) << result;
+    qCDebug(SNORE) << result;
 
     foreach(const Alert & alert, application.alerts()) {
         snarlInterface->AddClass(alert.name().toUtf8().constData(),
@@ -189,7 +192,7 @@ void SnarlBackend::slotRegisterApplication(const Application &application)
 void SnarlBackend::slotDeregisterApplication(const Application &application)
 {
     if (!m_applications.contains(application.name())) {
-        snoreDebug(SNORE_DEBUG) << "Unknown apllication: " << application.name();
+        qCDebug(SNORE) << "Unknown apllication: " << application.name();
         return;
     }
     SnarlInterface *snarlInterface = m_applications.take(application.name());
@@ -201,7 +204,7 @@ void SnarlBackend::slotDeregisterApplication(const Application &application)
 void SnarlBackend::slotNotify(Notification notification)
 {
     if (!m_applications.contains(notification.application().name())) {
-        snoreDebug(SNORE_DEBUG) << "Unknown apllication: " << notification.application().name();
+        qCDebug(SNORE) << "Unknown apllication: " << notification.application().name();
         return;
     }
 
@@ -217,7 +220,7 @@ void SnarlBackend::slotNotify(Notification notification)
     }
 
     ULONG32 id = 0;
-    snoreDebug(SNORE_DEBUG) << notification.icon();
+    qCDebug(SNORE) << notification.icon();
 
     if (!notification.isUpdate()) {
         id = snarlInterface->Notify(notification.alert().name().toUtf8().constData(),
@@ -254,7 +257,7 @@ void SnarlBackend::slotNotify(Notification notification)
 void SnarlBackend::slotCloseNotification(Notification notification)
 {
     if (!m_applications.contains(notification.application().name())) {
-        snoreDebug(SNORE_DEBUG) << "Unknown apllication: " << notification.application().name();
+        qCDebug(SNORE) << "Unknown apllication: " << notification.application().name();
         return;
     }
     ULONG32 id = notification.hints().privateValue(this, "id").toUInt();
