@@ -25,11 +25,10 @@ class SnarlBackend: public Snore::SnoreBackend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreBackend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "snore_plugin.json")
 public:
     SnarlBackend();
     ~SnarlBackend();
-    Snore::PluginSettingsWidget *settingsWidget() override;
 
     virtual bool canCloseNotification() const override;
     virtual bool canUpdateNotification() const override;
@@ -41,14 +40,14 @@ protected:
 
 private:
     class SnarlWidget;
-    SnarlBackend::SnarlWidget *m_eventLoop;
+    SnarlBackend::SnarlWidget *m_eventLoop = nullptr;
     QHash<QString, Snarl::V42::SnarlInterface *> m_applications;
 
 public Q_SLOTS:
-    void slotRegisterApplication(const Snore::Application &application);
-    void slotDeregisterApplication(const Snore::Application &application);
-    void slotNotify(Snore::Notification notification);
-    void slotCloseNotification(Snore::Notification notification);
+    void slotRegisterApplication(const Snore::Application &application) override;
+    void slotDeregisterApplication(const Snore::Application &application) override;
+    void slotNotify(Snore::Notification notification) override;
+    void slotCloseNotification(Snore::Notification notification) override;
 
 private:
     QHash<LONG32, Snore::Notification> m_idMap;
