@@ -18,7 +18,6 @@
 
 #include "snorenotifier.h"
 #include "notifywidget.h"
-#include "snorenotifiersettings.h"
 #include "libsnore/notification/notification_p.h"
 #include "libsnore/snore_p.h"
 
@@ -35,14 +34,14 @@ SnoreNotifier::SnoreNotifier():
         m_widgets[i] = w;
         connect(w, &NotifyWidget::dismissed, [this, w]() {
             Notification notification = w->notification();
-            closeNotification(notification, Notification::DISMISSED);
+            closeNotification(notification, Notification::Dismissed);
             slotCloseNotification(notification);
         });
 
         connect(w, &NotifyWidget::invoked, [this, w]() {
             Notification notification = w->notification();
             slotNotificationActionInvoked(notification);
-            closeNotification(notification, Notification::ACTIVATED);
+            closeNotification(notification, Notification::Activated);
             slotCloseNotification(notification);
         });
     }
@@ -54,9 +53,7 @@ SnoreNotifier::SnoreNotifier():
 
 SnoreNotifier::~SnoreNotifier()
 {
-    for (auto w : m_widgets) {
-        w->deleteLater();
-    }
+    qDeleteAll(m_widgets);
 }
 
 void SnoreNotifier::slotNotify(Snore::Notification notification)
@@ -71,14 +68,14 @@ void SnoreNotifier::slotNotify(Snore::Notification notification)
         if (notification.old().hints().privateValue(this, "id").isValid()) {
             NotifyWidget *w = m_widgets[notification.old().hints().privateValue(this, "id").toInt()];
             if (w->notification().isValid() && w->notification().id() == notification.old().id()) {
-                snoreDebug(SNORE_DEBUG) << "replacing notification" << w->notification().id() << notification.id();
+                qCDebug(SNORE) << "replacing notification" << w->notification().id() << notification.id();
                 display(w, notification);
             }
         } else {
             for (int i = 0; i < m_queue.length(); ++i) {
                 Notification n = m_queue.at(i);
                 if (n.id() == notification.old().id()) {
-                    snoreDebug(SNORE_DEBUG) << "replacing qued notification" << n.id() << notification.id();
+                    qCDebug(SNORE) << "replacing qued notification" << n.id() << notification.id();
                     m_queue.replace(i, notification);
                 }
             }
@@ -86,7 +83,7 @@ void SnoreNotifier::slotNotify(Snore::Notification notification)
         return;
     }
     if (m_queue.isEmpty()) {
-        for (NotifyWidget *w : m_widgets) {
+        foreach(NotifyWidget * w, m_widgets) {
             if (w->acquire(notification.timeout())) {
                 display(w, notification);
                 return;
@@ -94,7 +91,7 @@ void SnoreNotifier::slotNotify(Snore::Notification notification)
         }
     }
     m_queue.append(notification);
-    snoreDebug(SNORE_DEBUG) << "queing" << m_queue.size();
+    qCDebug(SNORE) << "queueing" << m_queue.size();
     if (!m_timer->isActive()) {
         m_timer->start();
     }
@@ -110,10 +107,10 @@ void SnoreNotifier::slotCloseNotification(Snore::Notification notification)
 void SnoreNotifier::slotQueueTimeout()
 {
     if (m_queue.isEmpty()) {
-        snoreDebug(SNORE_DEBUG) << "queue is empty";
+        qCDebug(SNORE) << "queue is empty";
         m_timer->stop();
     } else {
-        for (NotifyWidget *w : m_widgets) {
+        foreach(NotifyWidget * w, m_widgets) {
             if (!m_queue.isEmpty() && w->acquire(m_queue.first().timeout())) {
                 Notification notification = m_queue.takeFirst();
                 notification.hints().setPrivateValue(this, "id", w->id());
@@ -134,13 +131,8 @@ bool SnoreNotifier::canUpdateNotification() const
     return true;
 }
 
-PluginSettingsWidget *SnoreNotifier::settingsWidget()
-{
-    return new SnoreNotifierSettings(this);
-}
-
 void SnoreNotifier::setDefaultSettings()
 {
-    setDefaultSettingsValue(QLatin1String("Position"), Qt::TopRightCorner);
+    setDefaultSettingsValue(QStringLiteral("Position"), Qt::TopRightCorner);
     SnoreBackend::setDefaultSettings();
 }
