@@ -27,7 +27,7 @@ class SnoreNotifier : public Snore::SnoreBackend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreBackend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "snore_plugin.json")
 public:
     SnoreNotifier();
     ~SnoreNotifier();
@@ -35,8 +35,6 @@ public:
     bool canCloseNotification() const override;
     bool canUpdateNotification() const override;
 
-    Snore::PluginSettingsWidget *settingsWidget() override;
-
 protected:
     void setDefaultSettings() override;
 public Q_SLOTS:
