@@ -18,7 +18,8 @@
 #ifndef SNORENOTIFIERSETTINGS_H
 #define SNORENOTIFIERSETTINGS_H
 
-#include "plugins/pluginsettingswidget.h"
+#include "libsnore/settings/pluginsettingswidget.h"
+#include "libsnore/plugins/settingsplugin.h"
 
 namespace Snore
 {
@@ -39,4 +40,6 @@ private:
     QComboBox *m_comboBox;
 };
 
+SNORE_DECLARE_SETTINGS_PLUGIN(SnoreNotifierSettings)
+
 #endif // SNORENOTIFIERSETTINGS_H
