@@ -4,6 +4,8 @@
 #include "libsnore/utils.h"
 
 #include <QSystemTrayIcon>
+#include <QApplication>
+
 using namespace Snore;
 
 TrayIconNotifer::TrayIconNotifer()
@@ -25,7 +27,7 @@ void TrayIconNotifer::slotNotify(Notification notification)
         m_notificationQue.append(notification);
         displayNotification(icon);
     } else {
-        closeNotification(notification, Notification::CLOSED);
+        closeNotification(notification, Notification::Closed);
         setErrorString(QLatin1String("No tray-icon hint provided for ") + notification.application().name());
     }
 }
@@ -34,7 +36,7 @@ void TrayIconNotifer::slotCloseNotification(Notification n)
 {
     QSystemTrayIcon *icon = trayIcon(n.application());
     if (icon) {
-        snoreDebug(SNORE_DEBUG) << n;
+        qCDebug(SNORE) << n;
         m_currentlyDisplaying = false;
         displayNotification(icon);
     }
@@ -44,7 +46,7 @@ void TrayIconNotifer::slotRegisterApplication(const Application &application)
 {
     QSystemTrayIcon *icon = trayIcon(application);
     if (icon) {
-        connect(icon, SIGNAL(messageClicked()), this, SLOT(actionInvoked()));
+        connect(icon, &QSystemTrayIcon::messageClicked, this, &TrayIconNotifer::actionInvoked);
     }
 }
 
@@ -52,7 +54,7 @@ void TrayIconNotifer::slotDeregisterApplication(const Application &application)
 {
     QSystemTrayIcon *icon = trayIcon(application);
     if (icon) {
-        disconnect(icon, SIGNAL(messageClicked()), this, SLOT(actionInvoked()));
+        disconnect(icon, &QSystemTrayIcon::messageClicked, this, &TrayIconNotifer::actionInvoked);
     }
 }
 
@@ -87,10 +89,19 @@ void TrayIconNotifer::actionInvoked()
     QSystemTrayIcon *icon = trayIcon(n.application());
     if (icon && n.isValid()) {
         slotNotificationActionInvoked(n);
-        closeNotification(n, Notification::ACTIVATED);
+        closeNotification(n, Notification::Activated);
         m_currentlyDisplaying = false;
         displayNotification(icon);
     }
 
 }
 
+bool TrayIconNotifer::isReady()
+{
+    if (!qobject_cast< QApplication * >(qApp)) {
+        setErrorString(tr("This plugin only works with QApplication"));
+        return false;
+    }
+    return true;
+}
+
