@@ -13,12 +13,13 @@ class TrayIconNotifer: public Snore::SnoreBackend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreBackend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationBackend/1.0" FILE "snore_plugin.json")
 public:
     TrayIconNotifer();
     ~TrayIconNotifer() = default;
 
-    virtual bool canCloseNotification() const override;
+    bool canCloseNotification() const override;
+    bool isReady() override;
 
 public Q_SLOTS:
     void slotNotify(Snore::Notification notification) override;
