@@ -27,7 +27,7 @@ class FreedesktopFrontend : public Snore::SnoreFrontend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreFrontend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationFrontend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationFrontend/1.0" FILE "snore_plugin.json")
 public:
     FreedesktopFrontend();
     ~FreedesktopFrontend() = default;
