@@ -21,54 +21,25 @@
 #include "libsnore/plugins/snorefrontend.h"
 #include "libsnore/application.h"
 
-#include <QNetworkAccessManager>
-#include <QPointer>
-
-class QWebSocket;
+#include "pushoverclient.h"
 
 class PushoverFrontend : public Snore::SnoreFrontend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreFrontend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationFrontend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationFrontend/1.0" FILE "snore_plugin.json")
 public:
     PushoverFrontend();
     ~PushoverFrontend() = default;
 
-    Snore::PluginSettingsWidget *settingsWidget() override;
-
-    void login(const QString &email, const QString &password, const QString &deviceName);
-    void logOut();
-
-    bool isLoggedIn() const;
-    QString errorMessage();
-
 protected:
     void setDefaultSettings() override;
 
 public Q_SLOTS:
-    void slotActionInvoked(Snore::Notification notification);
-    void connectToService();
-
-Q_SIGNALS:
-    void loggedInChanged(bool isLoggedIn);
-    void error(QString error);
+    void slotActionInvoked(Snore::Notification notification) override;
 
 private:
-    QNetworkAccessManager m_manager;
-    QPointer<QWebSocket> m_socket;
-    bool m_loggedIn = false;
-    QString m_errorMessage;
-
-    QString secret();
-    QString device();
-
-    void disconnectService();
-
-    void registerDevice(const QString &secret, const QString &deviceName);
-    void getMessages();
-    void deleteMessages(int latestMessageId);
-    void acknowledgeNotification(Snore::Notification notification);
+    PushoverClient *m_client;
 
 };
 
