@@ -18,7 +18,10 @@
 #ifndef PUSHOVERSETTINGS_H
 #define PUSHOVERSETTINGS_H
 
-#include "plugins/pluginsettingswidget.h"
+#include "libsnore/settings/pluginsettingswidget.h"
+#include "libsnore/plugins/settingsplugin.h"
+
+#include "pushoverclient.h"
 
 class QLineEdit;
 class QPushButton;
@@ -40,10 +43,13 @@ private:
     QLineEdit *m_deviceLineEdit;
     QPushButton *m_registerButton;
     QLabel *m_errorMessageLabel;
+    PushoverClient::LoginState m_state = PushoverClient::Undefined;
 
 private Q_SLOTS:
-    void slotUpdateLoginState(bool state);
+    void slotUpdateLoginState(PushoverClient::LoginState state);
 
 };
 
+SNORE_DECLARE_SETTINGS_PLUGIN(PushoverSettings)
+
 #endif // PUSHOVERSETTINGS_H
