@@ -52,8 +52,8 @@ SnarlNetworkFrontend::~SnarlNetworkFrontend()
 void SnarlNetworkFrontend::slotActionInvoked(Snore::Notification notification)
 {
     if (notification.isActiveIn(this)) {
-        snoreDebug(SNORE_DEBUG) << notification.closeReason();
-        callback(notification, QLatin1String("SNP/1.1/304/Notification acknowledged/"));
+        qCDebug(SNORE) << notification.closeReason();
+        callback(notification, QStringLiteral("SNP/1.1/304/Notification acknowledged/"));
     }
 }
 
@@ -62,17 +62,17 @@ void SnarlNetworkFrontend::slotNotificationClosed(Snore::Notification notificati
 
     if (notification.removeActiveIn(this)) {
         switch (notification.closeReason()) {
-        case Notification::TIMED_OUT:
-            callback(notification, QLatin1String("SNP/1.1/303/Notification timed out/"));
+        case Notification::TimedOut:
+            callback(notification, QStringLiteral("SNP/1.1/303/Notification timed out/"));
             break;
-        case Notification::ACTIVATED:
-            callback(notification, QLatin1String("SNP/1.1/307/Notification closed/"));
+        case Notification::Activated:
+            callback(notification, QStringLiteral("SNP/1.1/307/Notification closed/"));
             break;
-        case Notification::DISMISSED:
-            callback(notification, QLatin1String("SNP/1.1/302/Notification cancelled/"));
+        case Notification::Dismissed:
+            callback(notification, QStringLiteral("SNP/1.1/302/Notification cancelled/"));
             break;
         default:
-            snoreDebug(SNORE_WARNING) << "Unhandled close reason" << notification.closeReason();
+            qCWarning(SNORE) << "Unhandled close reason" << notification.closeReason();
         }
     }
 }
@@ -80,16 +80,16 @@ void SnarlNetworkFrontend::slotNotificationClosed(Snore::Notification notificati
 void SnarlNetworkFrontend::handleConnection()
 {
     QTcpSocket *client = tcpServer->nextPendingConnection();
-    connect(client, SIGNAL(readyRead()), this, SLOT(handleMessages()));
-    connect(client, SIGNAL(disconnected()), client, SLOT(deleteLater()));
+    connect(client, &QTcpSocket::readyRead, this, &SnarlNetworkFrontend::handleMessages);
+    connect(client, &QTcpSocket::disconnected, client, &QTcpSocket::deleteLater);
 }
 
 void SnarlNetworkFrontend::handleMessages()
 {
-    const QString out(QLatin1String("SNP/1.1/0/OK"));
+    const QString out(QStringLiteral("SNP/1.1/0/OK"));
     QTcpSocket *client = qobject_cast<QTcpSocket *>(sender());
 
-    QStringList messages(QString::fromLatin1(client->readAll()).trimmed().split(QLatin1String("\r\n")));
+    QStringList messages(QString::fromLatin1(client->readAll()).trimmed().split(QStringLiteral("\r\n")));
     foreach(const QString & s, messages) {
         if (s.isEmpty()) {
             continue;
@@ -106,7 +106,7 @@ void SnarlNetworkFrontend::handleMessages()
     }
 }
 
-void SnarlNetworkFrontend::callback(Notification &sn, const QString msg)
+void SnarlNetworkFrontend::callback(Notification &sn, const QString &msg)
 {
     if (sn.hints().containsPrivateValue(this, "clientSocket")) {
         QTcpSocket *client = sn.hints().privateValue(this, "clientSocket").value<QPointer<QTcpSocket>>();
