@@ -19,7 +19,6 @@
 #ifndef SNARLNETWORK_H
 #define SNARLNETWORK_H
 #include "libsnore/plugins/snorefrontend.h"
-#include "libsnore/log.h"
 #include "parser.h"
 
 #include <QTcpSocket>
@@ -29,7 +28,7 @@ class SnarlNetworkFrontend : public Snore::SnoreFrontend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreFrontend)
-    Q_PLUGIN_METADATA(IID "org.Snore.NotificationFrontend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.NotificationFrontend/1.0" FILE "snore_plugin.json")
     friend class Parser;
 public:
     static const int port = 9887;
@@ -51,11 +50,11 @@ private:
     Parser *parser;
     QHash<QTcpSocket *, Snore::Application> m_applications;
 
-    void callback(Snore::Notification &sn, QString msg);
+    void callback(Snore::Notification &sn, const QString &msg);
 
     inline void write(QTcpSocket *dest, const QString &msg)
     {
-        snoreDebug(SNORE_DEBUG) << msg;
+        qCDebug(SNORE) << msg;
         dest->write(msg.toLatin1());
     }
 
