@@ -16,9 +16,7 @@
     along with SnoreNotify.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "nma.h"
-#include "nmasettings.h"
 
-#include "libsnore/log.h"
 #include "libsnore/utils.h"
 
 #include <QNetworkReply>
@@ -28,7 +26,7 @@ using namespace Snore;
 
 void NotifyMyAndroid::slotNotify(Notification notification)
 {
-    QString key = settingsValue(QLatin1String("ApiKey")).toString();
+    QString key = settingsValue(QStringLiteral("ApiKey")).toString();
     if (key.isEmpty()) {
         return;
     }
@@ -43,8 +41,8 @@ void NotifyMyAndroid::slotNotify(Notification notification)
                    + QLatin1String("&description=");
 
     if (notification.constHints().value("supports-markup").toBool()) {
-        data += notification.text(Utils::HREF | Utils::BOLD | Utils::BREAK |
-                                  Utils::UNDERLINE | Utils::FONT | Utils::ITALIC)
+        data += notification.text(Utils::Href | Utils::Bold | Utils::Break |
+                                  Utils::Underline | Utils::Font | Utils::Italic)
                 + QLatin1String("&content-type=text/html");
     } else {
         data += notification.text();
@@ -52,21 +50,16 @@ void NotifyMyAndroid::slotNotify(Notification notification)
 
     QNetworkReply *reply =  m_manager.post(request, data.toUtf8().constData());
     connect(reply, &QNetworkReply::finished, [reply]() {
-        snoreDebug(SNORE_DEBUG) << reply->error();
-        snoreDebug(SNORE_DEBUG) << reply->readAll();
+        qCDebug(SNORE) << reply->error();
+        qCDebug(SNORE) << reply->readAll();
         reply->close();
         reply->deleteLater();
     });
 
 }
 
-PluginSettingsWidget *NotifyMyAndroid::settingsWidget()
-{
-    return new NotifyMyAndroidSettings(this);
-}
-
 void NotifyMyAndroid::setDefaultSettings()
 {
-    setDefaultSettingsValue(QLatin1String("ApiKey"), QString());
+    setDefaultSettingsValue(QStringLiteral("ApiKey"), QString());
     SnoreSecondaryBackend::setDefaultSettings();
 }
