@@ -16,9 +16,7 @@
     along with SnoreNotify.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "pushover.h"
-#include "pushoversettings.h"
 
-#include "libsnore/log.h"
 #include "libsnore/utils.h"
 #include "libsnore/notification/notification_p.h"
 
@@ -34,7 +32,7 @@ void Pushover::slotNotify(Notification notification)
         return;
     }
 
-    QString key = settingsValue(QLatin1String("UserKey")).toString();
+    QString key = settingsValue(QStringLiteral("UserKey")).toString();
     if (key.isEmpty()) {
         return;
     }
@@ -49,7 +47,7 @@ void Pushover::slotNotify(Notification notification)
 
     QString textString;
     if (notification.constHints().value("use-markup").toBool()) {
-        textString = notification.text(Utils::HREF | Utils::BOLD | Utils::UNDERLINE | Utils::FONT | Utils::ITALIC);
+        textString = notification.text(Utils::Href | Utils::Bold | Utils::Underline | Utils::Font | Utils::Italic);
 
         QHttpPart html;
         html.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant(QLatin1String("form-data; name=\"html\"")));
@@ -61,8 +59,8 @@ void Pushover::slotNotify(Notification notification)
 
     QHttpPart text;
     text.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant(QLatin1String("form-data; name=\"message\"")));
-    snoreDebug(SNORE_DEBUG) << "Use Markup" << notification.constHints().value("use-markup").toBool();
-    snoreDebug(SNORE_DEBUG) << "Message" << textString;
+    qCDebug(SNORE) << "Use Markup" << notification.constHints().value("use-markup").toBool();
+    qCDebug(SNORE) << "Message" << textString;
     text.setBody(textString.toUtf8().constData());
     mp->append(text);
 
@@ -70,7 +68,7 @@ void Pushover::slotNotify(Notification notification)
     priority.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant(QLatin1String("form-data; name=\"priority\"")));
     priority.setBody(QString::number(notification.priority()).toUtf8().constData());
     mp->append(priority);
-    if (notification.priority() == Notification::EMERGENCY) {
+    if (notification.priority() == Notification::Emergency) {
 
         QHttpPart retry;
         retry.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant(QLatin1String("form-data; name=\"retry\"")));
@@ -88,14 +86,14 @@ void Pushover::slotNotify(Notification notification)
     if (notification.hints().value("silent").toBool()) {
         sound.setBody("none");
     } else {
-        sound.setBody(settingsValue(QLatin1String("Sound"), LOCAL_SETTING).toString().toUtf8().constData());
+        sound.setBody(settingsValue(QStringLiteral("Sound"), LocalSetting).toString().toUtf8().constData());
     }
     mp->append(sound);
 
-    if (!settingsValue(QLatin1String("Devices"), LOCAL_SETTING).toString().isEmpty()) {
+    if (!settingsValue(QStringLiteral("Devices"), LocalSetting).toString().isEmpty()) {
         QHttpPart devices;
         devices.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant(QLatin1String("form-data; name=\"device\"")));
-        devices.setBody(settingsValue(QLatin1String("Devices"), LOCAL_SETTING).toString().toUtf8().constData());
+        devices.setBody(settingsValue(QStringLiteral("Devices"), LocalSetting).toString().toUtf8().constData());
         mp->append(devices);
     }
 
@@ -113,23 +111,18 @@ void Pushover::slotNotify(Notification notification)
     mp->setParent(reply);
 
     connect(reply, &QNetworkReply::finished, [reply]() {
-        snoreDebug(SNORE_DEBUG) << reply->error();
-        snoreDebug(SNORE_DEBUG) << reply->readAll();
+        qCDebug(SNORE) << reply->error();
+        qCDebug(SNORE) << reply->readAll();
         reply->close();
         reply->deleteLater();
     });
 
 }
 
-PluginSettingsWidget *Pushover::settingsWidget()
-{
-    return new PushoverSettings(this);
-}
-
 void Pushover::setDefaultSettings()
 {
-    setDefaultSettingsValue(QLatin1String("UserKey"), QString());
-    setDefaultSettingsValue(QLatin1String("Sound"), QLatin1String("pushover"), LOCAL_SETTING);
-    setDefaultSettingsValue(QLatin1String("Devices"), QString(), LOCAL_SETTING);
+    setDefaultSettingsValue(QStringLiteral("UserKey"), QString());
+    setDefaultSettingsValue(QStringLiteral("Sound"), QLatin1String("pushover"), LocalSetting);
+    setDefaultSettingsValue(QStringLiteral("Devices"), QString(), LocalSetting);
     SnoreSecondaryBackend::setDefaultSettings();
 }
