@@ -26,13 +26,11 @@ class Pushover : public Snore::SnoreSecondaryBackend
 {
     Q_OBJECT
     Q_INTERFACES(Snore::SnoreSecondaryBackend)
-    Q_PLUGIN_METADATA(IID "org.Snore.SecondaryNotificationBackend/1.0" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID "org.Snore.SecondaryNotificationBackend/1.0" FILE "snore_plugin.json")
 public:
     Pushover() = default;
     ~Pushover() = default;
 
-    Snore::PluginSettingsWidget *settingsWidget() override;
-
 protected:
     void setDefaultSettings() override;
 
