@@ -18,7 +18,8 @@
 #ifndef PUSHOVERSETTINGS_H
 #define PUSHOVERSETTINGS_H
 
-#include "plugins/pluginsettingswidget.h"
+#include "libsnore/settings/pluginsettingswidget.h"
+#include "libsnore/plugins/settingsplugin.h"
 
 class QLineEdit;
 
@@ -39,4 +40,6 @@ private:
 
 };
 
+SNORE_DECLARE_SETTINGS_PLUGIN(PushoverSettings)
+
 #endif // PUSHOVERSETTINGS_H
