@@ -16,9 +16,6 @@
     along with SnoreNotify.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "sound.h"
-#include "soundsettings.h"
-
-#include "libsnore/log.h"
 
 #include <QtMultimedia/QMediaPlayer>
 #include <QTimer>
@@ -29,21 +26,16 @@ Sound::Sound():
     m_player(new QMediaPlayer(this))
 {
 //    connect(m_player,QMediaPlayer::positionChanged,[](qint64 pos){
-//        snoreDebug(SNORE_DEBUG) << "Player: " << pos;
+//        qCDebug(SNORE) << "Player: " << pos;
 //    });
     connect(m_player, &QMediaPlayer::stateChanged, [](QMediaPlayer::State state) {
-        snoreDebug(SNORE_DEBUG) << "Player: " << state;
+        qCDebug(SNORE) << "Player: " << state;
     });
 }
 
-PluginSettingsWidget *Sound::settingsWidget()
-{
-    return new SoundSettings(this);
-}
-
 void Sound::setDefaultSettings()
 {
-    setDefaultSettingsValue(QLatin1String("Volume"), 50);
+    setDefaultSettingsValue(QStringLiteral("Volume"), 50);
     SnoreSecondaryBackend::setDefaultSettings();
 }
 
@@ -52,16 +44,16 @@ void Sound::slotNotificationDisplayed(Snore::Notification notification)
     if (notification.hints().value("silent").toBool()) {
         return;
     }
-    m_player->setVolume(settingsValue(QLatin1String("Volume")).toInt());
+    m_player->setVolume(settingsValue(QStringLiteral("Volume")).toInt());
 
     QString sound = notification.hints().value("sound").toString();
     if (sound.isEmpty()) {
-        sound = settingsValue(QLatin1String("Sound")).toString();
+        sound = settingsValue(QStringLiteral("Sound")).toString();
     }
-    snoreDebug(SNORE_DEBUG) << "SoundFile:" << sound;
+    qCDebug(SNORE) << "SoundFile:" << sound;
     if (!sound.isEmpty()) {
         m_player->setMedia(QUrl::fromLocalFile(sound));
-        snoreDebug(SNORE_DEBUG) << "SoundFile:" << m_player->media().canonicalUrl();
+        qCDebug(SNORE) << "SoundFile:" << m_player->media().canonicalUrl();
         m_player->play();
         QTimer *timeout = new QTimer(this);
         timeout->setSingleShot(true);
