@@ -16,9 +16,7 @@
     along with SnoreNotify.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "toasty.h"
-#include "toastysettings.h"
 
-#include "libsnore/log.h"
 #include "libsnore/utils.h"
 
 #include <QNetworkReply>
@@ -30,7 +28,7 @@ using namespace Snore;
 
 void Toasty::slotNotify(Notification notification)
 {
-    QString key = settingsValue(QLatin1String("DeviceID")).toString();
+    QString key = settingsValue(QStringLiteral("DeviceID")).toString();
     if (key.isEmpty()) {
         return;
     }
@@ -66,21 +64,16 @@ void Toasty::slotNotify(Notification notification)
     file->setParent(reply);
 
     connect(reply, &QNetworkReply::finished, [reply]() {
-        snoreDebug(SNORE_DEBUG) << reply->error();
-        snoreDebug(SNORE_DEBUG) << reply->readAll();
+        qCDebug(SNORE) << reply->error();
+        qCDebug(SNORE) << reply->readAll();
         reply->close();
         reply->deleteLater();
     });
 
 }
 
-PluginSettingsWidget *Toasty::settingsWidget()
-{
-    return new ToastySettings(this);
-}
-
 void Toasty::setDefaultSettings()
 {
-    setDefaultSettingsValue(QLatin1String("DeviceID"), QString());
+    setDefaultSettingsValue(QStringLiteral("DeviceID"), QString());
     SnoreSecondaryBackend::setDefaultSettings();
 }
