@@ -36,27 +36,6 @@ public:
     explicit SettingsWindow(const QString &appName, QWidget *parent = 0);
     ~SettingsWindow();
 
-    static QStringList knownApps();
-
-    static QSettings &settings();
-
-    template<typename Func>
-    static QStringList allSettingsKeysWithPrefix(const QString &prefix, QSettings &settings, Func fun)
-    {
-        QStringList groups = prefix.split(QLatin1Char('/'));
-        QStringList out;
-
-        for (const QString group : groups) {
-            settings.beginGroup(group);
-        }
-        out = fun(settings);
-
-        for (int i = 0; i < groups.size(); ++i) {
-            settings.endGroup();
-        }
-        return out;
-    }
-
 private Q_SLOTS:
     void on_buttonBox_clicked(QAbstractButton *button);
     void on_comboBox_currentIndexChanged(const QString &arg1);
